import type { BaseContract, BigNumber, BigNumberish, BytesLike, CallOverrides, ContractTransaction, Overrides, PopulatedTransaction, Signer, utils } from "ethers";
import type { FunctionFragment, Result, EventFragment } from "@ethersproject/abi";
import type { Listener, Provider } from "@ethersproject/providers";
import type { TypedEventFilter, TypedEvent, TypedListener, OnEvent } from "./common.js";
export declare namespace ITWMultichainRegistry {
    type DeploymentStruct = {
        deploymentAddress: string;
        chainId: BigNumberish;
        metadataURI: string;
    };
    type DeploymentStructOutput = [string, BigNumber, string] & {
        deploymentAddress: string;
        chainId: BigNumber;
        metadataURI: string;
    };
}
export interface TWMultichainRegistryLogicInterface extends utils.Interface {
    functions: {
        "OPERATOR_ROLE()": FunctionFragment;
        "_msgData()": FunctionFragment;
        "_msgSender()": FunctionFragment;
        "add(address,address,uint256,string)": FunctionFragment;
        "contractType()": FunctionFragment;
        "contractVersion()": FunctionFragment;
        "count(address)": FunctionFragment;
        "getAll(address)": FunctionFragment;
        "getMetadataUri(uint256,address)": FunctionFragment;
        "remove(address,address,uint256)": FunctionFragment;
    };
    getFunction(nameOrSignatureOrTopic: "OPERATOR_ROLE" | "_msgData" | "_msgSender" | "add" | "contractType" | "contractVersion" | "count" | "getAll" | "getMetadataUri" | "remove"): FunctionFragment;
    encodeFunctionData(functionFragment: "OPERATOR_ROLE", values?: undefined): string;
    encodeFunctionData(functionFragment: "_msgData", values?: undefined): string;
    encodeFunctionData(functionFragment: "_msgSender", values?: undefined): string;
    encodeFunctionData(functionFragment: "add", values: [string, string, BigNumberish, string]): string;
    encodeFunctionData(functionFragment: "contractType", values?: undefined): string;
    encodeFunctionData(functionFragment: "contractVersion", values?: undefined): string;
    encodeFunctionData(functionFragment: "count", values: [string]): string;
    encodeFunctionData(functionFragment: "getAll", values: [string]): string;
    encodeFunctionData(functionFragment: "getMetadataUri", values: [BigNumberish, string]): string;
    encodeFunctionData(functionFragment: "remove", values: [string, string, BigNumberish]): string;
    decodeFunctionResult(functionFragment: "OPERATOR_ROLE", data: BytesLike): Result;
    decodeFunctionResult(functionFragment: "_msgData", data: BytesLike): Result;
    decodeFunctionResult(functionFragment: "_msgSender", data: BytesLike): Result;
    decodeFunctionResult(functionFragment: "add", data: BytesLike): Result;
    decodeFunctionResult(functionFragment: "contractType", data: BytesLike): Result;
    decodeFunctionResult(functionFragment: "contractVersion", data: BytesLike): Result;
    decodeFunctionResult(functionFragment: "count", data: BytesLike): Result;
    decodeFunctionResult(functionFragment: "getAll", data: BytesLike): Result;
    decodeFunctionResult(functionFragment: "getMetadataUri", data: BytesLike): Result;
    decodeFunctionResult(functionFragment: "remove", data: BytesLike): Result;
    events: {
        "Added(address,address,uint256,string)": EventFragment;
        "Deleted(address,address,uint256)": EventFragment;
    };
    getEvent(nameOrSignatureOrTopic: "Added"): EventFragment;
    getEvent(nameOrSignatureOrTopic: "Deleted"): EventFragment;
}
export interface AddedEventObject {
    deployer: string;
    deployment: string;
    chainId: BigNumber;
    metadataUri: string;
}
export type AddedEvent = TypedEvent<[
    string,
    string,
    BigNumber,
    string
], AddedEventObject>;
export type AddedEventFilter = TypedEventFilter<AddedEvent>;
export interface DeletedEventObject {
    deployer: string;
    deployment: string;
    chainId: BigNumber;
}
export type DeletedEvent = TypedEvent<[
    string,
    string,
    BigNumber
], DeletedEventObject>;
export type DeletedEventFilter = TypedEventFilter<DeletedEvent>;
export interface TWMultichainRegistryLogic extends BaseContract {
    connect(signerOrProvider: Signer | Provider | string): this;
    attach(addressOrName: string): this;
    deployed(): Promise<this>;
    interface: TWMultichainRegistryLogicInterface;
    queryFilter<TEvent extends TypedEvent>(event: TypedEventFilter<TEvent>, fromBlockOrBlockhash?: string | number | undefined, toBlock?: string | number | undefined): Promise<Array<TEvent>>;
    listeners<TEvent extends TypedEvent>(eventFilter?: TypedEventFilter<TEvent>): Array<TypedListener<TEvent>>;
    listeners(eventName?: string): Array<Listener>;
    removeAllListeners<TEvent extends TypedEvent>(eventFilter: TypedEventFilter<TEvent>): this;
    removeAllListeners(eventName?: string): this;
    off: OnEvent<this>;
    on: OnEvent<this>;
    once: OnEvent<this>;
    removeListener: OnEvent<this>;
    functions: {
        OPERATOR_ROLE(overrides?: CallOverrides): Promise<[string]>;
        _msgData(overrides?: CallOverrides): Promise<[string]>;
        _msgSender(overrides?: CallOverrides): Promise<[string] & {
            sender: string;
        }>;
        add(_deployer: string, _deployment: string, _chainId: BigNumberish, metadataUri: string, overrides?: Overrides & {
            from?: string | Promise<string>;
        }): Promise<ContractTransaction>;
        contractType(overrides?: CallOverrides): Promise<[string]>;
        contractVersion(overrides?: CallOverrides): Promise<[number]>;
        count(_deployer: string, overrides?: CallOverrides): Promise<[BigNumber] & {
            deploymentCount: BigNumber;
        }>;
        getAll(_deployer: string, overrides?: CallOverrides): Promise<[
            ITWMultichainRegistry.DeploymentStructOutput[]
        ] & {
            allDeployments: ITWMultichainRegistry.DeploymentStructOutput[];
        }>;
        getMetadataUri(_chainId: BigNumberish, _deployment: string, overrides?: CallOverrides): Promise<[string] & {
            metadataUri: string;
        }>;
        remove(_deployer: string, _deployment: string, _chainId: BigNumberish, overrides?: Overrides & {
            from?: string | Promise<string>;
        }): Promise<ContractTransaction>;
    };
    OPERATOR_ROLE(overrides?: CallOverrides): Promise<string>;
    _msgData(overrides?: CallOverrides): Promise<string>;
    _msgSender(overrides?: CallOverrides): Promise<string>;
    add(_deployer: string, _deployment: string, _chainId: BigNumberish, metadataUri: string, overrides?: Overrides & {
        from?: string | Promise<string>;
    }): Promise<ContractTransaction>;
    contractType(overrides?: CallOverrides): Promise<string>;
    contractVersion(overrides?: CallOverrides): Promise<number>;
    count(_deployer: string, overrides?: CallOverrides): Promise<BigNumber>;
    getAll(_deployer: string, overrides?: CallOverrides): Promise<ITWMultichainRegistry.DeploymentStructOutput[]>;
    getMetadataUri(_chainId: BigNumberish, _deployment: string, overrides?: CallOverrides): Promise<string>;
    remove(_deployer: string, _deployment: string, _chainId: BigNumberish, overrides?: Overrides & {
        from?: string | Promise<string>;
    }): Promise<ContractTransaction>;
    callStatic: {
        OPERATOR_ROLE(overrides?: CallOverrides): Promise<string>;
        _msgData(overrides?: CallOverrides): Promise<string>;
        _msgSender(overrides?: CallOverrides): Promise<string>;
        add(_deployer: string, _deployment: string, _chainId: BigNumberish, metadataUri: string, overrides?: CallOverrides): Promise<void>;
        contractType(overrides?: CallOverrides): Promise<string>;
        contractVersion(overrides?: CallOverrides): Promise<number>;
        count(_deployer: string, overrides?: CallOverrides): Promise<BigNumber>;
        getAll(_deployer: string, overrides?: CallOverrides): Promise<ITWMultichainRegistry.DeploymentStructOutput[]>;
        getMetadataUri(_chainId: BigNumberish, _deployment: string, overrides?: CallOverrides): Promise<string>;
        remove(_deployer: string, _deployment: string, _chainId: BigNumberish, overrides?: CallOverrides): Promise<void>;
    };
    filters: {
        "Added(address,address,uint256,string)"(deployer?: string | null, deployment?: string | null, chainId?: BigNumberish | null, metadataUri?: null): AddedEventFilter;
        Added(deployer?: string | null, deployment?: string | null, chainId?: BigNumberish | null, metadataUri?: null): AddedEventFilter;
        "Deleted(address,address,uint256)"(deployer?: string | null, deployment?: string | null, chainId?: BigNumberish | null): DeletedEventFilter;
        Deleted(deployer?: string | null, deployment?: string | null, chainId?: BigNumberish | null): DeletedEventFilter;
    };
    estimateGas: {
        OPERATOR_ROLE(overrides?: CallOverrides): Promise<BigNumber>;
        _msgData(overrides?: CallOverrides): Promise<BigNumber>;
        _msgSender(overrides?: CallOverrides): Promise<BigNumber>;
        add(_deployer: string, _deployment: string, _chainId: BigNumberish, metadataUri: string, overrides?: Overrides & {
            from?: string | Promise<string>;
        }): Promise<BigNumber>;
        contractType(overrides?: CallOverrides): Promise<BigNumber>;
        contractVersion(overrides?: CallOverrides): Promise<BigNumber>;
        count(_deployer: string, overrides?: CallOverrides): Promise<BigNumber>;
        getAll(_deployer: string, overrides?: CallOverrides): Promise<BigNumber>;
        getMetadataUri(_chainId: BigNumberish, _deployment: string, overrides?: CallOverrides): Promise<BigNumber>;
        remove(_deployer: string, _deployment: string, _chainId: BigNumberish, overrides?: Overrides & {
            from?: string | Promise<string>;
        }): Promise<BigNumber>;
    };
    populateTransaction: {
        OPERATOR_ROLE(overrides?: CallOverrides): Promise<PopulatedTransaction>;
        _msgData(overrides?: CallOverrides): Promise<PopulatedTransaction>;
        _msgSender(overrides?: CallOverrides): Promise<PopulatedTransaction>;
        add(_deployer: string, _deployment: string, _chainId: BigNumberish, metadataUri: string, overrides?: Overrides & {
            from?: string | Promise<string>;
        }): Promise<PopulatedTransaction>;
        contractType(overrides?: CallOverrides): Promise<PopulatedTransaction>;
        contractVersion(overrides?: CallOverrides): Promise<PopulatedTransaction>;
        count(_deployer: string, overrides?: CallOverrides): Promise<PopulatedTransaction>;
        getAll(_deployer: string, overrides?: CallOverrides): Promise<PopulatedTransaction>;
        getMetadataUri(_chainId: BigNumberish, _deployment: string, overrides?: CallOverrides): Promise<PopulatedTransaction>;
        remove(_deployer: string, _deployment: string, _chainId: BigNumberish, overrides?: Overrides & {
            from?: string | Promise<string>;
        }): Promise<PopulatedTransaction>;
    };
}
//# sourceMappingURL=TWMultichainRegistryLogic.d.ts.map